@@ -29,7 +29,9 @@ except ImportError:
         default_size=(720, 790),
         monospace_display=True
     ):
-        pass
+        def wrapper(f):
+            return ""
+        return wrapper
 
 try:
     from deeplcretrainer import cnn_functions
